// This program is created for LPC-H2138 board
// RTC and Interrupt

#include "system.h"
#include "led.h"
#include "rtc.h"
#include "interrupts.h"
#include <inarm.h>


/**** INTERRUPTS HANDLERS ****/
// IRQ interrupt handler.
//__irq __arm void irq_handler(void)
#pragma vector=0x18
__irq __arm void IRQ_ISR_Handler (void)
{
  void (*interrupt_function)();
  unsigned int vector;

  // Called at 1000 Hz rate.
  vector = VICVectAddr; // Get interrupt vector.
  interrupt_function = (void(*)())vector;
  (*interrupt_function)(); // Call vectored interrupt function.

  VICVectAddr = 0; // Clear interrupt in VIC.
}

// FIQ interrupt handler.
//__fiq __arm void fiq_handler (void)
#pragma vector=0x1c
__fiq __arm void FIQ_ISR_Handler (void)
{
  void (*interrupt_function)();
  unsigned int vector;

  vector = VICVectAddr;     // Get interrupt vector.
  interrupt_function = (void(*)())vector;
  (*interrupt_function)();  // Call vectored interrupt function.

  VICVectAddr = 0; // Clear interrupt in VIC.
}



void RTCInterrupt()
{
  (*RTC_function)();
}



void rtc_int()
{
  LedOn();      //on led
  Delay(1000);  //delay
  LedOff();     //off led
  ILR=0x3;      // clear all interrupt of RTC
}


int main()
{

  /**** INITIALIZATION ****/
  FrecInit();      //Frequency initialization
  LedInit();       //Init led
  InitRTC();       //RTC Ini


  /**** INTERRUPTS ****/
  MEMMAP = 1;                         //This will move the exception vectors in place.
  __disable_interrupt();              //Disable interrupts.
  InitRTCInterrupt(rtc_int);          //Setup interrupt controller.
  __enable_interrupt();               //Enable interrupts.


  while(1)
  {

  }

}
